(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    200161,       6727]
NotebookOptionsPosition[    196501,       6602]
NotebookOutlinePosition[    196839,       6617]
CellTagsIndexPosition[    196796,       6614]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Orthogonal Projection Derivative Filters on the BCC Lattice", "Title",
 CellChangeTimes->{{3.458058964372697*^9, 3.4580589763254757`*^9}, {
  3.458071822462929*^9, 3.458071822586882*^9}}],

Cell[CellGroupData[{

Cell["Definitions of the Building Block Functions", "Section",
 CellChangeTimes->{{3.458059118047406*^9, 3.45805914297819*^9}}],

Cell[CellGroupData[{

Cell["Helper functions and definitions of 1D B-splines", "Subsection",
 CellChangeTimes->{{3.458059023587874*^9, 3.45805904952489*^9}, {
  3.4580591711060534`*^9, 3.4580591752759533`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"1", "/", "2"}], "*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.443902114154986*^9, 3.4439021834877768`*^9}, {
  3.458058958417066*^9, 3.458058961909067*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sbs", "[", 
    RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
   RowBox[{"InverseFourierTransform", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], "*", "w"}], "]"}]}], 
        RowBox[{"I", "*", "w"}]], ")"}], 
      RowBox[{"n", "+", "1"}]], ",", "w", ",", "x", ",", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.443902189095229*^9, 3.443902235745463*^9}, {
  3.4439025938716393`*^9, 3.443902635947359*^9}, {3.443902668193769*^9, 
  3.44390272953152*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Box0", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"0", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tent", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"1", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quad", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"2", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cubic", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"3", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quartic", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"4", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tentprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Box0", "[", "x", "]"}], "-", 
     RowBox[{"Box0", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quadprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Tent", "[", "x", "]"}], "-", 
     RowBox[{"Tent", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cubicprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Quad", "[", "x", "]"}], "-", 
     RowBox[{"Quad", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quarticprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Cubic", "[", "x", "]"}], "-", 
     RowBox[{"Cubic", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.443902601674026*^9, 3.443902602551865*^9}, {
  3.443902715225357*^9, 3.4439028466284246`*^9}, {3.443902982829195*^9, 
  3.443903016105946*^9}, {3.443903521598184*^9, 3.4439035394022837`*^9}, {
  3.443905449556735*^9, 3.443905504064172*^9}, {3.443905826532113*^9, 
  3.443905879852861*^9}, {3.443905953253234*^9, 3.4439059917211943`*^9}, {
  3.443906045432839*^9, 3.443906055995171*^9}, {3.443906100222641*^9, 
  3.443906112391561*^9}, {3.4439061509902573`*^9, 3.443906153920333*^9}, {
  3.4439062863602*^9, 3.4439063141302843`*^9}, {3.4439072655723677`*^9, 
  3.4439072756800327`*^9}, {3.444073361540482*^9, 3.4440733844820757`*^9}, {
  3.4440875777461357`*^9, 3.4440876079086037`*^9}, {3.4441484106060257`*^9, 
  3.444148453179571*^9}, {3.444149572752542*^9, 3.444149607091098*^9}, {
  3.445191381285131*^9, 3.445191423909698*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear, Quintic, Nonic, Tredecic and Septendecic Box Splines", \
"Subsection",
 CellChangeTimes->{{3.444087759883206*^9, 3.4440877691597567`*^9}, {
  3.444148612851123*^9, 3.4441486176491823`*^9}, {3.444149121610832*^9, 
  3.444149124331897*^9}, {3.4441501487655487`*^9, 3.444150150395426*^9}, {
  3.444681077924129*^9, 3.444681104143992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Box0", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "4"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.443902915300997*^9, 3.443902953949894*^9}, {
   3.443903033142562*^9, 3.443903045099889*^9}, {3.4439030789968643`*^9, 
   3.4439031458439503`*^9}, {3.443903228566423*^9, 3.443903229632222*^9}, 
   3.44407039319248*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Qbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Tent", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "8"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.443903702928653*^9, 3.443903738289247*^9}, 
   3.443903860593863*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Nbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Quad", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "12"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.4441501790570498`*^9, 3.444150191261592*^9}, {
  3.444681116074456*^9, 3.444681116433529*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Tdbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Cubic", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "16"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.444073920614644*^9, 3.444073949179372*^9}, {
   3.444681122464025*^9, 3.444681122938513*^9}, 3.44519163024096*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sdbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Quartic", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "20"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.444149237585411*^9, 3.444149248574308*^9}, {
  3.444149279509204*^9, 3.44414928056634*^9}, {3.4446811263324413`*^9, 
  3.4446811275277*^9}, {3.445191632043971*^9, 3.445191638331767*^9}}],

Cell[TextData[{
 "A function that generates BCC points within the bounding box ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "n"}], ",", "n"}], "]"}], "3"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.444072648178198*^9, 3.444072668545528*^9}, {
   3.44407271078839*^9, 3.444072728904887*^9}, {3.444072857382187*^9, 
   3.4440728588739033`*^9}, {3.444072984489847*^9, 3.444072985850934*^9}, 
   3.44407305458512*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BCCpoints", "[", "n_", "]"}], ":=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Tuples", "[", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "n"}], ",", "n"}], "]"}], ",", "3"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], " ", ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], " ", ")"}]}], " ", 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.444072688982792*^9, 3.444072701607403*^9}, {
  3.444072861475195*^9, 3.444072874156608*^9}, {3.444073017014442*^9, 
  3.444073017614018*^9}, {3.444073069861034*^9, 3.444073070623472*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivative Filters", "Section",
 CellChangeTimes->{{3.458059181672471*^9, 3.4580592212133303`*^9}}],

Cell["\<\
The following filters are implemented according to equation (31) in the \
manuscript.\
\>", "Text",
 CellChangeTimes->{{3.458059233294991*^9, 3.4580592594985332`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "The Derivative of a Linear Box Spline orthogonally projected onto a Linear \
Box Spline (",
 StyleBox["LL",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.44519120505727*^9, 3.445191221696875*^9}, 
   3.458060047521139*^9, {3.458065916738306*^9, 3.458065921327458*^9}}],

Cell["\<\
This is tantamount to taking the derivative of a Quintic Box - Spline,\
\>", "Text",
 CellChangeTimes->{{3.4451912174170713`*^9, 3.445191240477462*^9}, 
   3.458059311553461*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CdLL", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Tentprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Tent", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "8"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.4451912884683743`*^9, {3.445191431233691*^9, 3.445191439332024*^9}, {
   3.4451917221195087`*^9, 3.44519172289611*^9}, {3.4451917803316717`*^9, 
   3.4451917804898653`*^9}, {3.445192250935299*^9, 3.445192251725933*^9}}],

Cell["and sampling it at the BCC Lattice sites.", "Text",
 CellChangeTimes->{{3.458059327031444*^9, 3.4580593464642973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CdLLx", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"CdLL", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", "1"}], "]"}]}], "}"}], " ", 
      "&"}], "/@", " ", 
     RowBox[{"BCCpoints", "[", "4", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.445191506775055*^9, 3.4451915170015087`*^9}, {
  3.445191794753683*^9, 3.4451917956601048`*^9}, {3.4451918332566442`*^9, 
  3.445191833367755*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "12"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "12"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "12"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "12"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "12"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.445191757523879*^9, 3.445191838225751*^9}, 
   3.445192257749249*^9, 3.445193232221119*^9, 3.445193264266369*^9, 
   3.445193938342188*^9, 3.4580601682587337`*^9, 3.458070332854459*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The Derivative of a Quintic Box Spline orthogonally projected onto a Linear \
Box Spline (",
 StyleBox["QL",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.4439063492969427`*^9, 3.443906417324007*^9}, 
   3.4580600501278*^9, {3.458065890464328*^9, 3.458065911338752*^9}}],

Cell["\<\
This is tantamount to taking the derivative of a Nonic (9th order \
polynomials, generated by the projection of 4D tensor product Quadratic \
B-Splines) Box Spline\
\>", "Text",
 CellChangeTimes->{{3.444150393428898*^9, 3.444150421392058*^9}, {
  3.444680480392125*^9, 3.444680482660377*^9}, {3.444680786280748*^9, 
  3.444680892974473*^9}, {3.444684048505219*^9, 3.444684057866568*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CdQL", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Quadprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Quad", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "12"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.443907641963463*^9, 3.443907711367188*^9}, {
   3.443908653211946*^9, 3.443908877439117*^9}, {3.4439089084336557`*^9, 
   3.4439089381576977`*^9}, 3.443908990691605*^9, {3.4439090601175833`*^9, 
   3.443909107926715*^9}, {3.443909139884972*^9, 3.443909145567589*^9}, {
   3.44390964373597*^9, 3.443909643845769*^9}, {3.443998410602449*^9, 
   3.443998410715806*^9}, {3.443999794637191*^9, 3.443999795833942*^9}, {
   3.443999836842203*^9, 3.443999851517392*^9}, {3.444000331801544*^9, 
   3.444000331974608*^9}, {3.444000394896213*^9, 3.444000395913232*^9}, {
   3.4440005070775146`*^9, 3.444000507212111*^9}, 3.444149985152996*^9, 
   3.444156006091913*^9, 3.445192085223854*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CdQLx", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"CdQL", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", "1"}], "]"}]}], "}"}], " ", 
      "&"}], "/@", " ", 
     RowBox[{"BCCpoints", "[", "6", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4441510212296143`*^9, 3.444151067824181*^9}, {
   3.444151322222548*^9, 3.444151325822617*^9}, {3.444156418695614*^9, 
   3.4441564222675343`*^9}, 3.445192089192256*^9, 3.4451932485109777`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "336"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "336"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "336"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "336"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "1344"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["23", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1", "1344"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["23", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["79", "1120"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["23", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "1344"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["23", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1", "1344"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["187", "3360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["187", "3360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["187", "3360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["187", "3360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["3", "2240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["187", "3360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["187", "3360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["187", "3360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["187", "3360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1344"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["23", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1344"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["23", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["79", "1120"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["23", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1344"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["23", "2240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1344"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "336"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "336"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "336"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "336"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "2240"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4441515501112947`*^9, 3.444156482452918*^9, 
  3.444159836028676*^9, 3.44468416146128*^9, 3.445193232625187*^9, 
  3.4451932842729473`*^9, 3.4451939584335203`*^9, 3.458060203416915*^9, 
  3.458070360561039*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The Derivative of a Quintic Box Spline orthogonally projected onto a \
Quintic Box Spline (",
 StyleBox["QQ",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.445191892374556*^9, 3.445191955896719*^9}, {
  3.4451919968864594`*^9, 3.4451920169754353`*^9}, {3.458065934924542*^9, 
  3.458065938494625*^9}}],

Cell["\<\
This is tantamount to sampling the derivative of a Tredecic Box Spline \
(generated by Cubic B - Splines).\
\>", "Text",
 CellChangeTimes->{{3.445191996709499*^9, 3.44519206409787*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CdQQ", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cubicprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Cubic", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "16"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.44519213011796*^9, 3.445192180473812*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CdQQx", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"CdQQ", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", "1"}], "]"}]}], "}"}], " ", 
      "&"}], "/@", " ", 
     RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.445192198344434*^9, 3.445192211401208*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "2395008"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["17", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["17", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["5", "342144"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["173", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["5", "342144"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["173", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "660"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["173", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["5", "342144"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["173", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["5", "342144"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "855360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["1", "855360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["919", "142560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["919", "142560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["919", "142560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["919", "142560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "855360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["647", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["1", "855360"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["467", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["503", "187110"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["6623", "498960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["503", "187110"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["467", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["6623", "498960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["19477", "362880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["6623", "498960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["467", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["503", "187110"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["6623", "498960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["503", "187110"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["467", "3991680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["13", "1496880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["53", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["53", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["45803", "1197504"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["45803", "1197504"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["45803", "1197504"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["45803", "1197504"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["53", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["5011", "1995840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["53", "997920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["47", "11975040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["53", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["53", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["45803", "1197504"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["45803", "1197504"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["45803", "1197504"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["45803", "1197504"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["53", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5011", "1995840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["53", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["47", "11975040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["467", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["503", "187110"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6623", "498960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["503", "187110"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["467", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6623", "498960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19477", "362880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6623", "498960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["467", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["503", "187110"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6623", "498960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["503", "187110"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["467", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["13", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "855360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "855360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["919", "142560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["919", "142560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["919", "142560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["919", "142560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "855360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["647", "3991680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "855360"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5", "342144"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5", "342144"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "660"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5", "342144"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "997920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["5", "342144"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "1496880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "2395008"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.445192363813951*^9, 3.4451932452386627`*^9, 
  3.44519336862626*^9, 3.445194044439371*^9, 3.4580603552228603`*^9, 
  3.4580704436501417`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The derivative of a Nonic Box Spline orthogonally projected onto a Linear \
Box Spline (",
 StyleBox["NL",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.445192490215239*^9, 3.445192564946492*^9}, {
  3.4580659467095537`*^9, 3.458065951264432*^9}}],

Cell["\<\
This is also tantamount to taking the derivative of a Tredecic Box - Spline\
\>", "Text",
 CellChangeTimes->{{3.44519256662917*^9, 3.445192585191452*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CdNLx", " ", "=", " ", "CdQQx"}], ";"}]], "Input",
 CellChangeTimes->{{3.4451926007030153`*^9, 3.445192616173642*^9}, 
   3.445193861918911*^9, 3.458059402036057*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The Derivative of a Nonic Box Spline orthogonally projected onto a Quintic \
Box Spline (",
 StyleBox["NQ",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.444149886264536*^9, 3.444149887313233*^9}, {
   3.444149941234701*^9, 3.444149951166625*^9}, {3.4446805365118837`*^9, 
   3.444680539060627*^9}, 3.458059431022264*^9, {3.458065959277389*^9, 
   3.458065969089754*^9}}],

Cell["\<\
This amounts to taking the derivative of a Septendecic (17th order \
polynomial, generated by 4D tensor product Quartic B-Splines)  box  spline.\
\>", "Text",
 CellChangeTimes->{{3.444150348407319*^9, 3.4441503770481253`*^9}, {
  3.444150595009055*^9, 3.444150598279571*^9}, {3.444680905669236*^9, 
  3.4446809870051126`*^9}, {3.444684074130028*^9, 3.444684080860547*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CdNQ", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Quarticprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Quartic", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "20"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.444150009660165*^9, 3.444150032399331*^9}, {
   3.444150133569913*^9, 3.444150134623125*^9}, 3.445193084671748*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CdNQx", " ", "=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"CdNQ", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", "1"}], "]"}]}], "}"}], " ", 
      "&"}], "/@", " ", 
     RowBox[{"BCCpoints", "[", "10", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4441509477112837`*^9, 3.4441509908114653`*^9}, {
  3.444151300745585*^9, 3.444151306263465*^9}, {3.444159487519773*^9, 
  3.444159496479085*^9}, {3.44519308750951*^9, 3.4451930908427153`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["67", "5977939968"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["67", "5977939968"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["67", "5977939968"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["67", "5977939968"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["317", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["34037", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["317", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["34037", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["74167", "9963233280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["34037", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["317", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["34037", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["317", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "905748480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["17", "905748480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["2812801", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["2812801", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["2812801", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["2812801", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "905748480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["99427", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["17", "905748480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["1", "1811496960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["83819", "19926466560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["1", "1811496960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["75541", "543449088"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["1788509", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["75541", "543449088"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["83819", "19926466560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1788509", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["27077587", "9963233280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["1788509", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["83819", "19926466560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["75541", "543449088"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["1788509", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["75541", "543449088"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["1", "1811496960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["83819", "19926466560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["335", "569327616"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["1", "1811496960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9901", "355829760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["9901", "355829760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["11806073", "1423319040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["11806073", "1423319040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["11806073", "1423319040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["11806073", "1423319040"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9901", "355829760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["85321", "135862272"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["9901", "355829760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "5"}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["15373", "11955879936"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", "3"}], "}"}], ",", 
     FractionBox["731", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     FractionBox["19853", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["281", "1067489280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["11607821", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["281", "1067489280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["10927349", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["30805517", "2299207680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["10927349", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "6"}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["19853", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["11607821", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["30805517", "2299207680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["173942723", "4269957120"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["30805517", "2299207680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["11607821", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["19853", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["10927349", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["30805517", "2299207680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["10927349", "2717245440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "6"}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["281", "1067489280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["11607821", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["432799", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["281", "1067489280"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "6", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["19853", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "6", ",", "2"}], "}"}], ",", 
     FractionBox["173", "8539914240"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["3336451", "14944849920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["3336451", "14944849920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["202867141", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["202867141", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "7"}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["202867141", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["202867141", "7472424960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "7"}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["3336451", "14944849920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["182225761", "59779399680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["3336451", "14944849920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "5"}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["74801", "2846638080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "3"}], "}"}], ",", 
     FractionBox["10279", "29889699840"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "7", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "7", ",", "1"}], "}"}], ",", 
     FractionBox["19", "5434490880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3336451", "14944849920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3336451", "14944849920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["202867141", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["202867141", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "7"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["202867141", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["202867141", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "7"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3336451", "14944849920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["182225761", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3336451", "14944849920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74801", "2846638080"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10279", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19853", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["281", "1067489280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11607821", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["281", "1067489280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10927349", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["30805517", "2299207680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10927349", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "6"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19853", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11607821", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["30805517", "2299207680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173942723", "4269957120"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["30805517", "2299207680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11607821", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "6"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19853", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10927349", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["30805517", "2299207680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["10927349", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "6"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["281", "1067489280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11607821", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["432799", "5434490880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["281", "1067489280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19853", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["173", "8539914240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["9901", "355829760"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["9901", "355829760"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11806073", "1423319040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11806073", "1423319040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11806073", "1423319040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11806073", "1423319040"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["9901", "355829760"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["85321", "135862272"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["9901", "355829760"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["15373", "11955879936"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["731", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1811496960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["83819", "19926466560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1811496960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["75541", "543449088"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1788509", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["75541", "543449088"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["83819", "19926466560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1788509", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["27077587", "9963233280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1788509", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["83819", "19926466560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["75541", "543449088"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1788509", "2717245440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["75541", "543449088"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1811496960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["83819", "19926466560"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["335", "569327616"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1811496960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "905748480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "905748480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2812801", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2812801", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2812801", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2812801", "29889699840"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "905748480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["99427", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["17", "905748480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["317", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34037", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["317", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34037", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["74167", "9963233280"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34037", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["317", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34037", "59779399680"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["317", "7472424960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["67", "5977939968"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["67", "5977939968"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["67", "5977939968"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["67", "5977939968"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "8539914240"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.444150965746172*^9, 3.4441512270219917`*^9, 
  3.444151810028002*^9, 3.444160106438732*^9, 3.444684438559043*^9, 
  3.445193622334263*^9, 3.4451943064053097`*^9, 3.458060781243301*^9, 
  3.458070742954652*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Autocorrelation Sequences", "Section",
 CellChangeTimes->{{3.444070410075872*^9, 3.444070413610177*^9}, {
  3.444070718601562*^9, 3.444070724674505*^9}}],

Cell[CellGroupData[{

Cell["Linear Box Spline", "Subsection",
 CellChangeTimes->{{3.4440704269090357`*^9, 3.444070441619751*^9}}],

Cell["\<\
The autocorrelation sequence of the linear box spline is obtained by sampling \
the quintic box spline at the BCC lattice points that are within its support\
\>", "Text",
 CellChangeTimes->{{3.444070443814075*^9, 3.444070469889287*^9}, {
  3.4440706531445847`*^9, 3.44407066759969*^9}, {3.458059767062684*^9, 
  3.458059813179627*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ACLbs", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"Qbs", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], " ", "&"}], "/@",
      " ", 
     RowBox[{"BCCpoints", "[", "4", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.44407049901327*^9, 3.444070537420821*^9}, {
  3.444070585848407*^9, 3.44407063258554*^9}, {3.444073157998003*^9, 
  3.4440731601573467`*^9}, {3.444074024811576*^9, 3.444074034974963*^9}, {
  3.444079560687405*^9, 3.444079589942522*^9}, {3.444079649258772*^9, 
  3.444079656281678*^9}, {3.444084511902897*^9, 3.4440845633708363`*^9}, {
  3.4440846301822567`*^9, 3.444084635207862*^9}, {3.444084684868441*^9, 
  3.444084702664578*^9}, {3.444084873568184*^9, 3.44408493937088*^9}, {
  3.444085061306672*^9, 3.444085138097809*^9}, {3.4440864888792257`*^9, 
  3.444086557676358*^9}, {3.444086598652363*^9, 3.44408685897992*^9}, {
  3.444086988874069*^9, 3.444087004606789*^9}, {3.444087169001492*^9, 
  3.444087217805188*^9}, {3.444087261754135*^9, 3.444087336072988*^9}, {
  3.4441513518827953`*^9, 3.444151355088601*^9}, {3.444159512033887*^9, 
  3.444159518512145*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["2", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.444086769681367*^9, 3.444086807465488*^9}, {
   3.444086841735517*^9, 3.444086861857191*^9}, {3.444086995452767*^9, 
   3.444087007974142*^9}, 3.4440872212733173`*^9, {3.444087313900364*^9, 
   3.444087338859911*^9}, 3.44415181332075*^9, 3.44416010895007*^9, 
   3.444684441556587*^9, 3.445193625697359*^9, 3.445194309783876*^9, 
   3.458060785924776*^9, 3.458070746672675*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quintic Box Spline", "Subsection",
 CellChangeTimes->{{3.444150468743251*^9, 3.4441504724316683`*^9}}],

Cell["\<\
The autocorrelation of the Quintic box spline is obtained by sampling the \
Tredecic box spline\
\>", "Text",
 CellChangeTimes->{{3.444150488921187*^9, 3.444150519409925*^9}, {
  3.444683914963213*^9, 3.444683960499647*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ACQbs", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"Tdbs", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], " ", "&"}], "/@",
      " ", 
     RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4440873837533007`*^9, 3.444087388343289*^9}, {
   3.44408782641343*^9, 3.444087847719392*^9}, {3.4440879033487387`*^9, 
   3.444087907726513*^9}, {3.444088018872913*^9, 3.444088026153123*^9}, {
   3.444088313611372*^9, 3.444088318384737*^9}, {3.444151359819036*^9, 
   3.444151363539371*^9}, {3.444159522401957*^9, 3.444159525789607*^9}, {
   3.444683909315027*^9, 3.444683909844016*^9}, 3.445193670591243*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["40853", "270270"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1396301", "25945920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["3029911", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["54889", "6486480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1613", "1081080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["9743", "3538080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["719", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["1", "3706560"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["2383", "4864860"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["659", "15567552"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["59", "19459440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["167", "77837760"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "15567552"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4440874311315937`*^9, 3.444087889077162*^9, 
  3.444087948388397*^9, 3.444088067275791*^9, 3.444088359272072*^9, 
  3.4441518626362743`*^9, 3.444160149738414*^9, 3.444684483913082*^9, 
  3.445193626218457*^9, 3.445194366228167*^9, 3.458060866652314*^9, 
  3.458070802055472*^9}]
}, Open  ]],

Cell["Save The filters and the AC sequences", "Text",
 CellChangeTimes->{{3.444159596039147*^9, 3.4441596214622107`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<CdLLx.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "CdLLx"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<CdQLx.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "CdQLx"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<CdQQx.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "CdQQx"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<CdNLx.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "CdNLx"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<CdNQx.mat\>\"", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "CdNQx"}], ",", 
     "\"\<Mat\>\""}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<ACLbs.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "ACLbs"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<ACQbs.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "ACQbs"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4441596383327637`*^9, 3.4441596721570807`*^9}, {
  3.444159706580077*^9, 3.444159763899597*^9}, {3.444162938414432*^9, 
  3.444162970459539*^9}, {3.44416349157905*^9, 3.444163538502015*^9}, {
  3.444163760962672*^9, 3.444163813477745*^9}, {3.445192977510249*^9, 
  3.4451930588608637`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled Sequences", "Section",
 CellChangeTimes->{{3.444679510349351*^9, 3.444679513736635*^9}}],

Cell["\<\
These are useful when one wants to prefilter data so as to make the box \
splines interpolating\
\>", "Text",
 CellChangeTimes->{{3.444684566226469*^9, 3.444684592821166*^9}, {
  3.458059731379768*^9, 3.458059733988585*^9}}],

Cell[CellGroupData[{

Cell["Sampled Quintic", "Subsection",
 CellChangeTimes->{{3.444684601954885*^9, 3.444684613591902*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SSQbs", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"Qbs", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], " ", "&"}], "/@",
      " ", 
     RowBox[{"BCCpoints", "[", "4", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.444684931464981*^9, 3.444684993079762*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["2", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "30"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4446849484390182`*^9, {3.4446849806759987`*^9, 3.444684996021173*^9}, 
   3.4451936305061913`*^9, 3.445194369406098*^9, 3.458060871224875*^9, 
   3.45807080470373*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled nonic", "Subsection",
 CellChangeTimes->{{3.444684632960917*^9, 3.444684638316403*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SSNbs", " ", "=", " ", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"Nbs", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], " ", "&"}], "/@",
      " ", 
     RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.44468463328804*^9, 3.444684633933429*^9}, {
  3.444685021789563*^9, 3.444685034112214*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["379", "1680"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["1177", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["7", "180"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["43", "10080"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1", "4032"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["17", "20160"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1", "10080"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.444685061559266*^9, 3.445193659458256*^9, 
  3.445194400635645*^9, 3.458060917210299*^9, 3.458070839251131*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled Trdecic", "Subsection",
 CellChangeTimes->{{3.445192726580296*^9, 3.445192730399111*^9}}],

Cell["\<\
This is the same as sampling the autocorrelation sequence of a quintic box \
spline\
\>", "Text",
 CellChangeTimes->{{3.45805968831399*^9, 3.458059722156042*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SSTbs", " ", "=", " ", "ACQbs"}], ";"}]], "Input",
 CellChangeTimes->{{3.445192755376329*^9, 3.4451927679780912`*^9}, {
   3.445193833251985*^9, 3.445193843794261*^9}, 3.458059712874425*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<SSQbs.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "SSQbs"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<SSNbs.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "SSNbs"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<SSTbs.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "SSTbs"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.444685128038959*^9, 3.444685146668871*^9}, {
  3.445192938167053*^9, 3.445192961040277*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 655},
WindowMargins->{{320, Automatic}, {Automatic, 72}},
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 193, 2, 194, "Title"],
Cell[CellGroupData[{
Cell[785, 28, 127, 1, 72, "Section"],
Cell[CellGroupData[{
Cell[937, 33, 188, 2, 36, "Subsection"],
Cell[1128, 37, 751, 23, 52, "Input"],
Cell[1882, 62, 774, 22, 76, "Input"],
Cell[2659, 86, 2925, 74, 192, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5621, 165, 349, 5, 36, "Subsection"],
Cell[5973, 172, 1026, 29, 143, "Input"],
Cell[7002, 203, 872, 27, 70, "Input"],
Cell[7877, 232, 898, 27, 70, "Input"],
Cell[8778, 261, 920, 27, 70, "Input"],
Cell[9701, 290, 994, 28, 70, "Input"],
Cell[10698, 320, 478, 12, 70, "Text"],
Cell[11179, 334, 1377, 38, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12605, 378, 105, 1, 70, "Section"],
Cell[12713, 381, 177, 4, 70, "Text"],
Cell[CellGroupData[{
Cell[12915, 389, 309, 8, 70, "Subsection"],
Cell[13227, 399, 188, 4, 70, "Text"],
Cell[13418, 405, 1930, 54, 70, "Input"],
Cell[15351, 461, 125, 1, 70, "Text"],
Cell[CellGroupData[{
Cell[15501, 466, 869, 25, 70, "Input"],
Cell[16373, 493, 2140, 73, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18562, 572, 311, 8, 70, "Subsection"],
Cell[18876, 582, 397, 7, 70, "Text"],
Cell[19276, 591, 2390, 60, 70, "Input"],
Cell[CellGroupData[{
Cell[21691, 655, 915, 25, 70, "Input"],
Cell[22609, 682, 10233, 362, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32891, 1050, 342, 9, 70, "Subsection"],
Cell[33236, 1061, 195, 4, 70, "Text"],
Cell[33434, 1067, 1754, 51, 70, "Input"],
Cell[CellGroupData[{
Cell[35213, 1122, 765, 23, 70, "Input"],
Cell[35981, 1147, 29633, 1037, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65663, 2190, 288, 8, 70, "Subsection"],
Cell[65954, 2200, 164, 3, 70, "Text"],
Cell[66121, 2205, 201, 4, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66359, 2214, 412, 10, 70, "Subsection"],
Cell[66774, 2226, 382, 6, 70, "Text"],
Cell[67159, 2234, 1826, 52, 70, "Input"],
Cell[CellGroupData[{
Cell[69010, 2290, 910, 25, 70, "Input"],
Cell[69923, 2317, 66694, 2270, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136678, 4594, 159, 2, 70, "Section"],
Cell[CellGroupData[{
Cell[136862, 4600, 107, 1, 70, "Subsection"],
Cell[136972, 4603, 345, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[137342, 4613, 1577, 35, 70, "Input"],
Cell[138922, 4650, 3002, 98, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[141973, 4754, 108, 1, 70, "Subsection"],
Cell[142084, 4757, 234, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[142343, 4766, 1121, 28, 70, "Input"],
Cell[143467, 4796, 32661, 1107, 70, "Output"]
}, Open  ]],
Cell[176143, 5906, 121, 1, 70, "Text"],
Cell[176267, 5909, 1983, 56, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178299, 5971, 102, 1, 70, "Section"],
Cell[178404, 5974, 234, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[178663, 5983, 103, 1, 70, "Subsection"],
Cell[CellGroupData[{
Cell[178791, 5988, 753, 23, 70, "Input"],
Cell[179547, 6013, 2794, 96, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[182390, 6115, 101, 1, 70, "Subsection"],
Cell[CellGroupData[{
Cell[182516, 6120, 801, 24, 70, "Input"],
Cell[183320, 6146, 11771, 407, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[195140, 6559, 103, 1, 70, "Subsection"],
Cell[195246, 6562, 172, 4, 70, "Text"],
Cell[195421, 6568, 225, 4, 70, "Input"],
Cell[195649, 6574, 812, 23, 70, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

